carly
=====

|CircleCI|_

.. |CircleCI| image:: https://circleci.com/gh/cjw296/carly/tree/master.svg?style=shield
.. _CircleCI: https://circleci.com/gh/cjw296/carly/tree/master


A tool for putting messages into and collecting responses from Twisted servers and clients using real networking.

"call me maybe"

Why carly? 'cos someone already took `Jepsen!`__

__ https://jepsen.io/
